==> 1.0.2.tar.gz: doc/AppleApi.md <==
# forestvpn_api.api.AppleApi

## Load the API package
```dart
import 'package:forestvpn_api/api.dart';
```

All URIs are relative to *https://api.forestvpn.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**appleStoreServerNotification**](AppleApi.md#appleStoreServerNotification) | **POST** /apple/ssn/ | Apple Store Server to Server Notifications
[**verifyReceipt**](AppleApi.md#verifyReceipt) | **POST** /apple/verify-receipt/ | Verify receipt


# **appleStoreServerNotification**
> appleStoreServerNotification(notification)

Apple Store Server to Server Notifications

### Example 
```dart
import 'package:forestvpn_api/api.dart';

var api_instance = new AppleApi();
var notification = new AppleStoreServerNotification(); // AppleStoreServerNotification | 

try { 
    api_instance.appleStoreServerNotification(notification);
} catch (e) {
    print("Exception when calling AppleApi->appleStoreServerNotification: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **notification** | [**AppleStoreServerNotification**](AppleStoreServerNotification.md)|  | 

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **verifyReceipt**
> AppleStoreUnifiedReceipt verifyReceipt(request)

Verify receipt

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//forestvpn_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//forestvpn_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new AppleApi();
var request = new AppleVerifyReceiptRequest(); // AppleVerifyReceiptRequest | 

try { 
    var result = api_instance.verifyReceipt(request);
    print(result);
} catch (e) {
    print("Exception when calling AppleApi->verifyReceipt: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **request** | [**AppleVerifyReceiptRequest**](AppleVerifyReceiptRequest.md)|  | 

### Return type

[**AppleStoreUnifiedReceipt**](AppleStoreUnifiedReceipt.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

==> 1.0.3.tar.gz: doc/AppleApi.md <==
# forestvpn_api.api.AppleApi

## Load the API package
```dart
import 'package:forestvpn_api/api.dart';
```

All URIs are relative to *https://api.forestvpn.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**appleStoreServerNotification**](AppleApi.md#appleStoreServerNotification) | **POST** /apple/ssn/ | Apple Store Server to Server Notifications
[**verifyReceipt**](AppleApi.md#verifyReceipt) | **POST** /apple/verify-receipt/ | Verify receipt


# **appleStoreServerNotification**
> appleStoreServerNotification(notification)

Apple Store Server to Server Notifications

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

var api_instance = AppleApi();
var notification = AppleStoreServerNotification(); // AppleStoreServerNotification | 

try { 
    api_instance.appleStoreServerNotification(notification);
} catch (e) {
    print("Exception when calling AppleApi->appleStoreServerNotification: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **notification** | [**AppleStoreServerNotification**](AppleStoreServerNotification.md)|  | 

### Return type

void (empty response body)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **verifyReceipt**
> AppleStoreUnifiedReceipt verifyReceipt(request)

Verify receipt

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

var api_instance = AppleApi();
var request = AppleVerifyReceiptRequest(); // AppleVerifyReceiptRequest | 

try { 
    var result = api_instance.verifyReceipt(request);
    print(result);
} catch (e) {
    print("Exception when calling AppleApi->verifyReceipt: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **request** | [**AppleVerifyReceiptRequest**](AppleVerifyReceiptRequest.md)|  | 

### Return type

[**AppleStoreUnifiedReceipt**](AppleStoreUnifiedReceipt.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
